@@ -315,7 +315,7 @@ export default {
           speechRecognition.onstart = () => {
             started = true;
             final_transcript = '';
-            this.speechButton.style.background = "LightGoldenRodYellow";
+            this.speechButton.style.background = "greenyellow";
           };
           speechRecognition.onerror = () => {
             started = false;
@@ -359,7 +359,7 @@ export default {
       async createNode() {
         this.repo = await fetchPromptRepo()
 
-        this.node.innerHTML = `<h2>Codex Chat Notebook</h2><p>Built with OpenAI Codex, by Wei Ouyang</p>`
+        this.node.innerHTML = `<h2 style="color: slategrey;font-family: monospace;">Codex Chat Notebook</h2><p>Built with OpenAI Codex, by Wei Ouyang</p>`
         this.node.style.padding = "10px"
         this.node.style.background = "white";
         this.node.style.height = "100%";
@@ -375,6 +375,7 @@ export default {
         this.promptSelect = document.createElement('select')
         this.promptSelect.style.display = "block";
         this.promptSelect.style.width = "100%";
+        this.promptSelect.style.marginTop = "10px";
         this.promptSelect.style.color = "black";
         this.promptSelect.title = "Prompt";
         this.promptDetails = document.createElement('p')
@@ -412,6 +413,7 @@ export default {
         this.executeButton = document.createElement('button')
         this.executeButton.innerHTML = 'Execute'
         this.executeButton.style.display = "block";
+        this.executeButton.style.background = "lavender";
         this.executeButton.style.fontSize = "16px";
         this.executeButton.style.width = "100%";
         this.executeButton.classList.add("bp3-button", "bp3-minimal", "jp-ToolbarButtonComponent", "minimal", "jp-Button")
@@ -516,7 +518,7 @@ export default {
             console.error(e)
             alert(`Failed to execute: ${e}`)
           }
-          this.executeButton.style.background = "";
+          this.executeButton.style.background = "lavender";
           this.inputBox.value = '';
         }
         this.undoButton.onclick = async () => {
